@@ -167,6 +167,4 @@ print "elems: ", $DOCUMENT_HANDLER->{elements}, "\n";
 print "attrs: ", $DOCUMENT_HANDLER->{attrs}, "\n";
 print "whitespace: ", $DOCUMENT_HANDLER->{ws}, "\n";
 print "characters: ", $DOCUMENT_HANDLER->{chars}, "\n";
-
-
-__END__
+exit(0);
